def print_testlol(the_list,level=0):
    for each_item in the_list:
        if isinstance(each_item,list):
            print_testlol(each_item,level+1)
        else:
            for tab_stop in range(level):
                print("\t",end='')
            print(each_item)



from distutils.core import setup

setup(
    name = "wjtestPrint",
    version = "1.2.0",
    py_modules = ["WJTestPrint"],
    author = "wenjie",
    author_email = "826834678@qq.com",
    url = "http://www.baidu.com",
    description = "test",
    )
